@@ -13,6 +13,8 @@
 #'
 #' @inheritParams ggpiestats
 #' @inheritParams ggbetweenstats
+#' @param sample.size.label.args Additional aesthetic arguments that will be passed to
+#'   `ggplot2::geom_text()`.
 #'
 #' @inheritSection statsExpressions::contingency_table Contingency table analyses
 #'
@@ -44,7 +46,8 @@ ggbarstats <- function(data,
                        paired = FALSE,
                        results.subtitle = TRUE,
                        label = "percentage",
-                       label.args = list(alpha = 1, fill = "white"),
+                       label.args = list(alpha = 1.0, fill = "white"),
+                       sample.size.label.args = list(size = 4.0),
                        k = 2L,
                        proportion.test = results.subtitle,
                        perc.k = 0L,
@@ -53,7 +56,7 @@ ggbarstats <- function(data,
                        conf.level = 0.95,
                        sampling.plan = "indepMulti",
                        fixed.margin = "rows",
-                       prior.concentration = 1,
+                       prior.concentration = 1.0,
                        title = NULL,
                        subtitle = NULL,
                        caption = NULL,
@@ -127,8 +130,8 @@ ggbarstats <- function(data,
   plotBar <- ggplot(descriptive_df, aes({{ y }}, perc, fill = {{ x }})) +
     geom_bar(stat = "identity", position = "fill", color = "black") +
     scale_y_continuous(
-      labels       = function(x) paste0(x * 100, "%"),
-      breaks       = seq(from = 0, to = 1, by = 0.10),
+      labels       = function(x) paste0(x * 100L, "%"),
+      breaks       = seq(from = 0.0, to = 1.0, by = 0.10),
       minor_breaks = seq(from = 0.05, to = 0.95, by = 0.10)
     ) +
     exec(
@@ -157,10 +160,11 @@ ggbarstats <- function(data,
 
   # adding sample size info
   plotBar <- plotBar +
-    geom_text(
+    exec(
+      geom_text,
       data    = onesample_df,
       mapping = aes(x = {{ y }}, y = -0.05, label = N, fill = NULL),
-      size    = 4
+      !!!sample.size.label.args
     )
 
   # annotations ------------------------------------------
