@@ -133,13 +133,13 @@ ggcoefstats <- function(x,
                         subtitle = NULL,
                         caption = NULL,
                         only.significant = FALSE,
-                        point.args = list(size = 3, color = "blue", na.rm = TRUE),
+                        point.args = list(size = 3.0, color = "blue", na.rm = TRUE),
                         errorbar.args = list(height = 0, na.rm = TRUE),
                         vline = TRUE,
-                        vline.args = list(linewidth = 1, linetype = "dashed"),
+                        vline.args = list(linewidth = 1.0, linetype = "dashed"),
                         stats.labels = TRUE,
                         stats.label.color = NULL,
-                        stats.label.args = list(size = 3, direction = "y", min.segment.length = 0),
+                        stats.label.args = list(size = 3.0, direction = "y", min.segment.length = 0),
                         package = "RColorBrewer",
                         palette = "Dark2",
                         ggtheme = ggstatsplot::theme_ggstatsplot(),
