@@ -3,13 +3,13 @@ set.seed(123)
 survey_data <- dplyr::tibble(
   `1st survey` = c("Approve", "Approve", "Disapprove", "Disapprove"),
   `2nd survey` = c("Approve", "Disapprove", "Approve", "Disapprove"),
-  `Counts` = c(794L, 150L, 86L, 570L)
+  Counts = c(794L, 150L, 86L, 570L)
 )
 
 survey_data_NA <- dplyr::tibble(
   `1st survey` = c("Approve", "Approve", "Disapprove", "Disapprove"),
   `2nd survey` = c("Approve", "Disapprove", "Approve", "Disapprove"),
-  `Counts` = c(794L, 150L, NA_integer_, 570L)
+  Counts = c(794L, 150L, NA_integer_, 570L)
 )
 
 
