@@ -7,9 +7,7 @@ test_that("ggcoefstats doesn't work if no estimate column found", {
 # default plots for each statistic ------------------------------------------
 
 test_that("default plots are rendered correctly for each type of statistic", {
-  skip_if_not_installed("survival")
-
-  library(survival)
+  skip_if_not_installed("withr")
 
   set.seed(123)
   expect_doppelganger(
@@ -29,14 +27,6 @@ test_that("default plots are rendered correctly for each type of statistic", {
     fig = ggcoefstats(stats::aov(wt ~ mpg * am, mtcars), effectsize.type = "omega")
   )
 
-  set.seed(123)
-  expect_doppelganger(
-    title = "chi2-statistic",
-    fig = suppressWarnings(ggcoefstats(
-      survival::coxph(Surv(time, status) ~ age + sex + frailty(inst), lung)
-    ))
-  )
-
   df <- as.data.frame(Titanic)
 
   mod_glm <- stats::glm(
@@ -51,6 +41,17 @@ test_that("default plots are rendered correctly for each type of statistic", {
     title = "z-statistic",
     fig = ggcoefstats(mod_glm, conf.level = 0.90)
   )
+
+  skip_if_not_installed("survival")
+  withr::local_package("survival")
+
+  set.seed(123)
+  expect_doppelganger(
+    title = "chi2-statistic",
+    fig = suppressWarnings(ggcoefstats(
+      survival::coxph(Surv(time, status) ~ age + sex + frailty(inst), lung)
+    ))
+  )
 })
 
 df_meta <- tibble(
@@ -135,8 +136,12 @@ test_that(
     skip_if_not_installed("lme4")
     skip_on_os(c("windows", "linux", "solaris"))
 
-    library(lme4, warn.conflicts = FALSE)
-    m_lmer <- ggcoefstats(lmer(Reaction ~ Days + (Days | Subject), data = sleepstudy))
+    withr::local_package("lme4")
+    m_lmer <- ggcoefstats(
+      lme4::lmer(Reaction ~ Days + (Days | Subject),
+        data = lme4::sleepstudy
+      )
+    )
 
     expect_s3_class(m_lmer, "ggplot")
 
